@@ -37,14 +37,14 @@
 #' @examples \dontrun{
 #' ## See examples for fbOAuth to know how token was created.
 #' ## Getting information about Facebook's Facebook Page
-#'	load("fb_oauth")
-#'	fb_page <- getPage(page="facebook", token=fb_oauth)
+#'  load("fb_oauth")
+#'  fb_page <- getPage(page="facebook", token=fb_oauth)
 #' ## Getting posts on Humans of New York page, including posts by others users
 #' ## (not only owner of page)
 #'  page <- getPage(page="humansofnewyork", token=fb_oauth, feed=TRUE)
 #' ## Getting posts on Humans of New York page in January 2013
-#'  page <- getPage(page="humansofnewyork", token=fb_oauth, n=1000
-#'		since='2013/01/01', until='2013/01/31')
+#'  page <- getPage(page="humansofnewyork", token=fb_oauth, n=1000,
+#'    since='2013/01/01', until='2013/01/31')
 #' }
 #'
 
@@ -53,7 +53,7 @@ getPage <- function(page, token, n=100, since=NULL, until=NULL, feed=FALSE){
 
 	url <- paste0('https://graph.facebook.com/', page,
 		'/posts?fields=from,message,created_time,type,link,comments.summary(true)',
-		',likes.summary(true),shares&limit=')
+		',likes.summary(true),shares')
 	if (feed){
 		url <- paste0('https://graph.facebook.com/', page,
 		'/feed?fields=from,message,created_time,type,link,comments.summary(true)',
